# libthai-cffi

[![License](https://img.shields.io/badge/license-LGPL-blue.svg)](LICENSE)
[![PyPi](https://img.shields.io/pypi/v/libthai-cffi.svg)](https://pypi.python.org/pypi/libthai-cffi)

CFFI binding to libthai

libthai 0.1.25 is required

## Installation

Make sure that libthai is installed and it is at least 0.1.25.

Install this from pip:

```sh
$ pip install libthai-cffi
```

(you may want to write this in your requirements.txt)

## Contributing

To contribute to this project:

1.  Fork and clone this repository
2.  Run `python setup.py develop`
3.  Run `pip install pre-commit && pre-commit install`
4.  Start hacking
5.  Run test: `python setup.py test`
6.  Commit. Pre-commit will warn if you have any changes.
7.  Submit pull request on GitHub
8.  Make sure Travis tests pass.

## License

Licensed under the [GNU Lesser Public License](LICENSE) per libthai.
